#!/usr/bin/env python3

import randopass
import sys

def main():
    numWords = -1
    args = [a for a in sys.argv[1:]]
    if(len(args)>0):
        numWords = args[0]
        try:
            numWords = int(args[0])
        except:
            print("invalid argument")
            return
        print('Passphrase:\n',''.join(randopass.getPass(numWords)))
    else:
        print('Passphrase:\n',''.join(randopass.getPass()))

if __name__ == "__main__":
    main()



# -*- coding: utf-8 -*-

from setuptools import setup, find_packages


with open('README.md') as f:
    readme = f.read()

with open('LICENSE') as f:
    license = f.read()

setup(
    name='randopass',
    version='0.1.0',
    description='Generate easy but secure passphrases',
    long_description=readme,
    author='Mike Willems',
    author_email='themikewillems@gmail.com',
    url='https://github.com/mikewillems/randopass',
    license=license,
    packages=find_packages(exclude=('tests', 'docs'))
)